\name{GDALMajorObject}
\alias{GDALMajorObject}
\alias{getDescription}
\alias{getMetadata}
\alias{setMetadata}
\title{GDAL Driver Object}
\description{
  \code{GDALMajorObject} is a virtual base class for all GDAL objects.
}
\usage{
getDescription(object)

getMetadata(object, domain = "")

setMetadata(object, metadata)
}
\arguments{
  \item{object}{an object inheriting from GDALMajorObject}

  \item{domain}{the metadata domain (currently ignored)}

  \item{metadata}{a list of character strings}
}
\details{
  \describe{
    \item{\code{getDescription}:}{returns a descrption string associated
    with the object. No setter method is defined because GDAL dataset
    objects use the description to hold the filename attached to the
    dataset. It would not be good to change that mid-stream.}
  
    \item{\code{getMetadata}:}{returns a list of metadata strings. Keys
      are returned as item names in the list.}
  
    \item{\code{setMetadata}:}{sets the metadata to the supplied list of
      strings. List item names will be used to generate metadata key
      names.} 
  }
}

\references{}

\author{Timothy H. Keitt}

\seealso{See also \code{\link{GDALDriver}},
  \code{\link{GDALReadOnlyDataset}}, \code{\link{GDALDataset}} and
  \code{\link{GDALTransientDataset}}.}

\examples{

driver <- new('GDALDriver', getGDALDriverNames()[1])

setMetadata(driver, list(Key = 'Test metadata'))

getMetadata(driver)

rm(driver)

}
\keyword{methods}

