\name{GDALReadOnlyDataset}
\alias{GDALReadOnlyDataset}
\alias{getDriver}
\alias{copyDataset}
\alias{saveDataset}
\alias{saveDatasetAs}
\alias{closeDataset}
\alias{deleteDataset}
\alias{getRasterData}
\alias{getProjectionRef}
\title{GDAL Read-Only Dataset Object}
\description{
  \code{GDALReadOnlyDataset} is the base class for a GDAL Dataset
  classes. Only read operations are supported. Both \code{GDALDataset}
  and \code{GDALTransientDataset} inherit these read operations while
  providing additional write operations (see
  \code{\link{GDALDataset}}). \code{GDALReadOnlyDataset} inherits from
  \code{\link{GDALMajorObject}}.
}
\usage{
new(classname, filename, handle = NULL)

getDriver(dataset)

dim(dataset)

copyDataset(dataset, driver, strict = FALSE, options = '')

saveDataset(dataset, filename)

saveDatasetAs(dataset, filename, driver)

closeDataset(dataset)

deleteDataset(dataset)

getRasterData(dataset, band = 1, offset = c(0, 0),
              region.dim = dim(dataset), output.dim = region.dim,
              interleave = c(0, 0), as.is = FALSE) 

getProjectionRef(dataset)
}
\arguments{
  \item{classname}{One of 'GDALReadOnlyDataset', 'GDALDataset',
    'GDALTransientDataset'}
  
  \item{filename}{A string giving the file to read from or copy to}

  \item{handle}{Used internally; not for public consumption}
  
  \item{dataset}{An object inheriting from class 'GDALReadOnlyDataset'}
  
  \item{driver}{An object inheriting from class 'GDALDriver'}
  
  \item{strict}{A logical indicating strict copy}
  
  \item{options}{A driver-specific set of dataset creation options
    (currently ignored)}

  \item{band}{The band number (1-based) to read from}

  \item{offset}{Number of rows and columns from the origin (usually the
    upper left corner) to begin reading from}

  \item{region.dim}{The number of rows and columns to read from the
    dataset}

  \item{output.dim}{Number of rows and columns in the output data; if
    smaller than \code{region.dim} the data will be subsampled}

  \item{interleave}{Element and row stride while reading data; rarely
    needed}

  \item{as.is}{If false, scale the data to its natural units; if the
    case of thematic data, return the data as factors}
}
\details{
  \describe{
    \item{\code{new}:}{returns an dataset object pointing to an GDAL
      dataset (but see also \code{\link{GDALTransientDataset}}). All resource
      allocated by the low-level GDAL routines will automatically be freed
      when the dataset object is garbage collected.}
    
    \item{\code{getDriver}:}{returns and object of class
      \code{\link{GDALDriver}} that can be used to initialize other
      datasets.}
    
    \item{\code{dim}:}{return the dimensions of the dataset. For a
      single band dataset, a vector contaning the number of rows and columns
      is returned; multiband datasets return rows, columns and number of
      bands.}
    
    \item{\code{copyDataset}:}{generic method for copying dataset
      objects. The object returned will be a dataset of class
      \code{\link{GDALTransientDataset}}.}
    
    \item{\code{saveDataset}:}{generic method to save an dataset object to a
      file. The new dataset is returned invisibly.}
    
    \item{\code{saveDatasetAs}:}{generic method that allows saving a
      dataset to a new name, and to a different format if a driver is
      supplied. As a side effect, this function closes the current object and
      reopens it pointing to the newly created dataset. (Think of 'save as' in
      your word processor.)}
    
    \item{\code{closeDataset}:}{generic fuction that closes the dataset
      and frees any associated resources. This function is rarely
      needed. Low-level resources allocated within the underlying GDAL library
      are automatically freed when the R dataset object is garbage
      collected.}
    
    \item{\code{deleteDataset}:}{generic function that closes a dataset
      and removes any files associated with that dataset. Some file formats
      may use several files on disk and GDAL drivers have methods for deleting
      entire datasets. Use cautiously!}

    \item{\code{getRasterData}:}{retrieves data from the dataset.}
    
    \item{\code{getProjectionRef}:}{returns the geodetic projection in
      Well Known Text format.}

  }
}

\references{}

\author{Timothy H. Keitt}

\seealso{See also \code{\link{GDALDriver}}, \code{\link{GDALDataset}},
\code{\link{GDALTransientDataset}}.}

\examples{}

\keyword{methods}
